@@ -2,6 +2,7 @@
 
 # {{{ constants and imports
 
+from __future__ import absolute_import, division, print_function
 import urwid
 
 try:
@@ -15,7 +16,7 @@ from pudb.py3compat import PY3, execfile, raw_input, xrange, \
 if PY3:
     ELLIPSIS = '…'
 else:
-    ELLIPSIS = unicode('…', 'utf-8')
+    ELLIPSIS = unicode('…', 'utf-8')  # noqa: F821
 
 from pudb.debugger import CONFIG
 
@@ -73,6 +74,7 @@ def get_str_safe_types():
         "SliceType TypeType TracebackType UnboundMethodType XRangeType".split()
         if hasattr(types, s)) + (WatchEvalError,)
 
+
 STR_SAFE_TYPES = get_str_safe_types()
 
 # }}}
@@ -196,8 +198,8 @@ class VariableWidget(urwid.FlowWidget):
             # Unicode is supported, use single character ellipsis
             for i in xrange(len(text)):
                 if len(text[i]) > maxcol:
-                    text[i] = (unicode(text[i][:maxcol-1])
-                    + ELLIPSIS + unicode(text[i][maxcol:]))
+                    text[i] = (unicode(text[i][:maxcol-1])  # noqa: F821
+                            + ELLIPSIS + unicode(text[i][maxcol:]))  # noqa: F821
                     # XXX: This doesn't work.  It just gives a ?
                     # Strangely, the following does work (it gives the …
                     # three characters from the right):
@@ -214,6 +216,8 @@ class VariableWidget(urwid.FlowWidget):
     def keypress(self, size, key):
         return key
 
+# }}}
+
 
 custom_stringifier_dict = {}
 
@@ -250,7 +254,7 @@ def get_stringifier(iinfo):
             return lambda value: "ERROR: Invalid custom stringifier file."
         else:
             if "pudb_stringifier" not in custom_stringifier_dict:
-                print("%s does not contain a function named pudb_stringifier at"
+                print("%s does not contain a function named pudb_stringifier at "
                       "the module level." % iinfo.display_type)
                 raw_input("Hit enter:")
                 return lambda value: ("ERROR: Invalid custom stringifier file: "
@@ -260,9 +264,9 @@ def get_stringifier(iinfo):
                     str(custom_stringifier_dict["pudb_stringifier"](value)))
 
 
-# tree walking ----------------------------------------------------------------
-class ValueWalker:
+# {{{ tree walking
 
+class ValueWalker:
     PREFIX = "| "
 
     def __init__(self, frame_var_info):
@@ -278,12 +282,14 @@ class ValueWalker:
             self.add_item(prefix, label, repr(value), id_path, attr_prefix)
         elif isinstance(value, string_types):
             self.add_item(prefix, label, repr(value), id_path, attr_prefix)
+        elif value is None:
+            self.add_item(prefix, label, repr(value), id_path, attr_prefix)
         else:
             try:
                 displayed_value = get_stringifier(iinfo)(value)
             except Exception:
-                ## Unfortunately, anything can happen when calling str() or
-                ## repr() on a random object.
+                # Unfortunately, anything can happen when calling str() or
+                # repr() on a random object.
                 displayed_value = type_stringifier(value) \
                                 + " (!! %s error !!)" % iinfo.display_type
 
